@@ -4,12 +4,18 @@ yamlpage
 ========
 Flatpages based on files with yaml syntax
 
+Install
+-------
+    pip install yamlpage
+
+Usage
+-----
     >>> from yamlpage import YamlPage
     >>> p = YamlPage('./content')
 
 
 Put page
---------
+
     >>> url = '/my/url'
     >>> p.put(url, (
     ...     ('title', 'foo'),
@@ -26,7 +32,7 @@ Put page
 
 
 Get page
---------
+
     >>> p.get(url)
     {'body': 'foo\\nbar', 'title': 'foo'}
 
@@ -42,7 +48,7 @@ except ImportError:
     ImportError('You need to install libyaml for increase pyyaml perfomance')
 
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
 
 class YamlPage(object):
